Description Super class Public fields Methods
Executable process
Executable process
openEo.gdalcubes::Process -> ExecutableProcess
jobAttached job to the process
new()Initialize executable process
ExecutableProcess$new( id = NA, description = NA, parameters = NA, operation = NA, process = NULL )
idId or name of the proces
descriptionShortly what the process does
parametersUsed parameters in the process
operationFunction that executes the process
processProcesses which will be executed
execute()Run the operation including a generated list of parameters
ExecutableProcess$execute()
clone()The objects of this class are cloneable with this method.
ExecutableProcess$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.