Description Public fields Active bindings Methods
Job
Job
idId of the job
statusCurrent status of the job
processProcess of the job
createdWhen the job was created
titleTitle of the job
descriptionShortly description of the planned result
resultsResult of the executed process
outputFormat of the output
openEoGraphStore the openEo graph for the job info
output.folderSet a new output folder
new()Initialize job
Job$new(id = NA, process = NULL)
idId of the job
processProcess of the job
statusCurrent status of the job
createdWhen the job was created
titleTitle of the job
descriptionShortly description of the planned result
resultsResult of the executed process
setOutput()Set the output format
Job$setOutput(output)
outputFormat of the output
store()Store the job in the Session
Job$store()
load()Load the job properties from the stored jobs
Job$load()
run()Execute the executable process graph and store it in the results of the job
Job$run()
The executed job
jobInfo()Get information about the job
Job$jobInfo()
Info list
clone()The objects of this class are cloneable with this method.
Job$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.