Description Public fields Methods
Process graph
Process graph
process_graph_idId of the process graph
process_graphAttached process graph
titleTitle of the corresponding job
descriptionDescription fo the corresponding job
new()Initialize process graph
ProcessGraph$new( process_graph_id = NA, process_graph = NULL, title = NA, description = NA )
process_graph_idId of the process graph
process_graphAttached process graph
titleTitle of process graph
descriptionDescription of the process graph
load()Attach corresponding process graph
ProcessGraph$load()
store()Attach process graph to the Session
ProcessGraph$store()
buildExecutableProcessGraph()Call the private function loadProcess with given process graph and job
ProcessGraph$buildExecutableProcessGraph(job = NULL)
jobCurrent job
Executable process
Make an executable process for the given graph
param graph_list Graph to load the corresponding process param job Attach the job to the process
clone()The objects of this class are cloneable with this method.
ProcessGraph$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.