Description Public fields Methods
Session class
Session class
graphsUser defined process graphs
processesPackage processes
dataData of current Session
jobsStored jobs of current Session
new()Create a new session
SessionInstance$new(configuration = NULL)
configurationSession configuration
getEndpoints()Get endpoints
SessionInstance$getEndpoints()
endpoints
getConfig()Get configuration
SessionInstance$getConfig()
configuration
getToken()Get token
SessionInstance$getToken()
token
setToken()Assign this token to the session
SessionInstance$setToken(new)
newNew token
startSession()Start the session
SessionInstance$startSession()
setBaseUrl()Set base url
SessionInstance$setBaseUrl(port, host)
portWhich port is currently saved
hostWhich host is currently saved
getBaseUrl()Get base url
SessionInstance$getBaseUrl()
base url
initDirectory()initializes workspace and data paths
SessionInstance$initDirectory()
initEndpoints()biuld a df to add the endpoints later on
SessionInstance$initEndpoints()
createEndpoint()Create an endpoint
SessionInstance$createEndpoint( path, method, handler = NULL, filter = FALSE, serializer = serializer_unboxed_json() )
pathpath for the endpoint
methodtype of request
handlerfunction to be executed
filterdeactivate filter for several endpoints
serializerplumber serializer to be used
created Endpoint
assignData()Function to assign data of collection to the data path
SessionInstance$assignData(col)
colCollection of class 'Collection'
assignProcess()Function to assign the process to the Session
SessionInstance$assignProcess(pro)
proProcess of class 'Process'
assignJob()Function to assign a job to the Session
SessionInstance$assignJob(job)
jobJob of class 'Job'
runJob()Execute the job
SessionInstance$runJob(job)
jobJob to be executed
clone()The objects of this class are cloneable with this method.
SessionInstance$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.